Welcome to |project| documentation!
===================================

.. toctree::
   :maxdepth: 1

   history
   irc

.. tidelift-referral-banner::

.. include:: ../README.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

